@@ -40,12 +40,14 @@ class TextEmbedding:
 			cache_folder: Optional[str or Path] = None,
 			quantize: Union[bool, str] = None,
 			device: Optional[str] = None,
+			force_download: bool = False,
 			verbose: bool = False,
 			**kwargs
 	) -> None:
 		self.model_name = model_name
 		self.session = None
 		self.device = device
+		self.force_download = force_download
 		self._transformer_config = {}
 		
 		onnx_file = kwargs.get("onnx_file")
@@ -91,7 +93,8 @@ class TextEmbedding:
 
 		self.model_dir = download_onnx_model(
 			model_config=model_config,
-			cache_dir=cache_folder
+			cache_dir=cache_folder,
+			force_download=force_download
 		)
 		
 		# Load sentence-transformers' onnx model
